export type ModerationLogPayloads = {
  addCustomEmoji: {
    emoji: any
    emojiId: string
  }
  assignRole: {
    expiresAt: string | null
    roleId: string
    roleName: string
    userHost: string | null
    userId: string
    userUsername: string
  }
  clearQueue: Record<string, never>
  createAvatarDecoration: {
    avatarDecoration: any
    avaterDecorationId: string
  }
  createGlobalAnnouncement: {
    announcement: any
    announcementId: string
  }
  createInvitation: {
    invitations: any[]
  }
  createRole: {
    role: any
    roleId: string
  }
  createUserAnnouncement: {
    announcement: any
    announcementId: string
    userHost: string | null
    userId: string
    userUsername: string
  }
  deleteAvatarDecoration: {
    avatarDecoration: any
    avatarDecorationId: string
  }
  deleteCustomEmoji: {
    emoji: any
    emojiId: string
  }
  deleteDriveFile: {
    fileId: string
    fileUserHost: string | null
    fileUserId: string | null
    fileUserUsername: string | null
  }
  deleteGlobalAnnouncement: {
    announcement: any
    announcementId: string
  }
  deleteNote: {
    note: any
    noteId: string
    noteUserHost: string | null
    noteUserId: string
    noteUserUsername: string
  }
  deleteRole: {
    role: any
    roleId: string
  }
  deleteUserAnnouncement: {
    announcement: any
    announcementId: string
    userHost: string | null
    userId: string
    userUsername: string
  }
  markSensitiveDriveFile: {
    fileId: string
    fileUserHost: string | null
    fileUserId: string | null
    fileUserUsername: string | null
  }
  promoteQueue: Record<string, never>
  resetPassword: {
    userHost: string | null
    userId: string
    userUsername: string
  }
  resolveAbuseReport: {
    forwarded: boolean
    report: any
    reportId: string
  }
  suspend: {
    userHost: string | null
    userId: string
    userUsername: string
  }
  suspendRemoteInstance: {
    id: string
    host: string
  }
  unassignRole: {
    roleId: string
    roleName: string
    userHost: string | null
    userId: string
    userUsername: string
  }
  unmarkSensitiveDriveFile: {
    fileId: string
    fileUserHost: string | null
    fileUserId: string | null
    fileUserUsername: string | null
  }
  unsetUserAvatar: {
    fileId: string
    userHost: string | null
    userId: string
    userUsername: string
  }
  unsetUserBanner: {
    fileId: string
    userHost: string | null
    userId: string
    userUsername: string
  }
  unsuspend: {
    userHost: string | null
    userId: string
    userUsername: string
  }
  unsuspendRemoteInstance: {
    id: string
    host: string
  }
  updateAvatarDecoration: {
    after: any
    avatarDecorationId: string
    before: any
  }
  updateCustomEmoji: {
    after: any
    before: any
    emojiId: string
  }
  updateGlobalAnnouncement: {
    after: any
    announcementId: string
    before: any
  }
  updateRole: {
    after: any
    before: any
    roleId: string
  }
  updateUserAnnouncement: {
    after: any
    announcementId: string
    before: any
    userHost: string | null
    userId: string
    userUsername: string
  }
  updateUserNote: {
    after: string | null
    before: string | null
    userHost: string | null
    userId: string
    userUsername: string
  }
  updateServerSettings: {
    after: any | null
    before: any | null
  }
}

export const followersVisibilities = [
  'followers',
  'private',
  'public'
] as const

export const followingVisibilities = [
  'followers',
  'private',
  'public'
] as const

export const moderationLogTypes = [
  'addCustomEmoji',
  'assignRole',
  'clearQueue',
  'createAvatarDecoration',
  'createGlobalAnnouncement',
  'createInvitation',
  'createRole',
  'createUserAnnouncement',
  'deleteAvatarDecoration',
  'deleteCustomEmoji',
  'deleteDriveFile',
  'deleteGlobalAnnouncement',
  'deleteNote',
  'deleteRole',
  'deleteUserAnnouncement',
  'markSensitiveDriveFile',
  'promoteQueue',
  'resetPassword',
  'resolveAbuseReport',
  'suspend',
  'suspendRemoteInstance',
  'unassignRole',
  'unmarkSensitiveDriveFile',
  'unsetUserAvatar',
  'unsetUserBanner',
  'unsuspend',
  'unsuspendRemoteInstance',
  'updateAvatarDecoration',
  'updateCustomEmoji',
  'updateGlobalAnnouncement',
  'updateRole',
  'updateServerSettings',
  'updateUserAnnouncement',
  'updateUserNote'
] as const

export const mutedNoteReasons = [
  'manual',
  'other',
  'spam',
  'word'
] as const

export const noteVisibilities = [
  'followers',
  'home',
  'public',
  'specified'
] as const

export const notificationTypes = [
  'achievementEarned',
  'app',
  'follow',
  'followRequestAccepted',
  'groupInvited',
  'mention',
  'note',
  'pollEnded',
  'pollVote',
  'quote',
  'reaction',
  'receiveFollowRequest',
  'renote',
  'reply'
] as const

export const permissions = [
  'read:account',
  'read:blocks',
  'read:channels',
  'read:drive',
  'read:favorites',
  'read:flash',
  'read:flash-likes',
  'read:following',
  'read:gallery',
  'read:gallery-likes',
  'read:messaging',
  'read:mutes',
  'read:notifications',
  'read:page-likes',
  'read:pages',
  'read:reactions',
  'read:user-groups',
  'write:account',
  'write:blocks',
  'write:channels',
  'write:drive',
  'write:favorites',
  'write:flash',
  'write:flash-likes',
  'write:following',
  'write:gallery',
  'write:gallery-likes',
  'write:messaging',
  'write:mutes',
  'write:notes',
  'write:notifications',
  'write:page-likes',
  'write:pages',
  'write:reactions',
  'write:user-groups',
  'write:votes'
] as const
