import { ModerationLogPayloads } from '@/consts'
import {
  Announcement,
  EmojiDetailed,
  Page,
  User,
  UserDetailed
} from '@/autogen/models'

export type AnnouncementCreated = {
  announcement: Announcement
}

export type DateString = string

export type EmojiAdded = {
  emoji: EmojiDetailed
}

export type EmojiDeleted = {
  emojis: EmojiDetailed[]
}

export type EmojiUpdated = {
  emojis: EmojiDetailed[]
}

export type ID = string

export type ModerationLog = {
  id: ID
  user: UserDetailed | null
  userId: User['id']
  createdAt: DateString
} & ({
  info: ModerationLogPayloads['addCustomEmoji']
  type: 'addCustomEmoji'
} | {
  info: ModerationLogPayloads['assignRole']
  type: 'assignRole'
} | {
  info: ModerationLogPayloads['clearQueue']
  type: 'clearQueue'
} | {
  info: ModerationLogPayloads['createAvatarDecoration']
  type: 'createAvatarDecoration'
} | {
  info: ModerationLogPayloads['createGlobalAnnouncement']
  type: 'createGlobalAnnouncement'
} | {
  info: ModerationLogPayloads['createInvitation']
  type: 'createInvitation'
} | {
  info: ModerationLogPayloads['createUserAnnouncement']
  type: 'createUserAnnouncement'
} | {
  info: ModerationLogPayloads['createRole']
  type: 'createRole'
} | {
  info: ModerationLogPayloads['deleteAvatarDecoration']
  type: 'deleteAvatarDecoration'
} | {
  info: ModerationLogPayloads['deleteCustomEmoji']
  type: 'deleteCustomEmoji'
} | {
  info: ModerationLogPayloads['deleteDriveFile']
  type: 'deleteDriveFile'
} | {
  info: ModerationLogPayloads['deleteGlobalAnnouncement']
  type: 'deleteGlobalAnnouncement'
} | {
  info: ModerationLogPayloads['deleteNote']
  type: 'deleteNote'
} | {
  info: ModerationLogPayloads['deleteRole']
  type: 'deleteRole'
} | {
  info: ModerationLogPayloads['deleteUserAnnouncement']
  type: 'deleteUserAnnouncement'
} | {
  info: ModerationLogPayloads['markSensitiveDriveFile']
  type: 'markSensitiveDriveFile'
} | {
  info: ModerationLogPayloads['promoteQueue']
  type: 'promoteQueue'
} | {
  info: ModerationLogPayloads['resetPassword']
  type: 'resetPassword'
} | {
  info: ModerationLogPayloads['resolveAbuseReport']
  type: 'resolveAbuseReport'
} | {
  info: ModerationLogPayloads['suspend']
  type: 'suspend'
} | {
  info: ModerationLogPayloads['suspendRemoteInstance']
  type: 'suspendRemoteInstance'
} | {
  info: ModerationLogPayloads['unassignRole']
  type: 'unassignRole'
} | {
  info: ModerationLogPayloads['unmarkSensitiveDriveFile']
  type: 'unmarkSensitiveDriveFile'
} | {
  info: ModerationLogPayloads['unsetUserAvatar']
  type: 'unsetUserAvatar'
} | {
  info: ModerationLogPayloads['unsetUserBanner']
  type: 'unsetUserBanner'
} | {
  info: ModerationLogPayloads['unsuspend']
  type: 'unsuspend'
} | {
  info: ModerationLogPayloads['unsuspendRemoteInstance']
  type: 'unsuspendRemoteInstance'
} | {
  info: ModerationLogPayloads['updateAvatarDecoration']
  type: 'updateAvatarDecoration'
} | {
  info: ModerationLogPayloads['updateCustomEmoji']
  type: 'updateCustomEmoji'
} | {
  info: ModerationLogPayloads['updateGlobalAnnouncement']
  type: 'updateGlobalAnnouncement'
} | {
  info: ModerationLogPayloads['updateRole']
  type: 'updateRole'
} | {
  info: ModerationLogPayloads['updateServerSettings']
  type: 'updateServerSettings'
} | {
  info: ModerationLogPayloads['updateUserAnnouncement']
  type: 'updateUserAnnouncement'
} | {
  info: ModerationLogPayloads['updateUserNote']
  type: 'updateUserNote'
})

export type PageEvent = {
  event: string
  pageId: Page['id']
  user: User
  userId: User['id']
  var: any
}

export type QueueStats = {
  deliver: {
    active: number
    activeSincePrevTick: number
    delayed: number
    waiting: number
  }
  inbox: {
    active: number
    activeSincePrevTick: number
    delayed: number
    waiting: number
  }
}

export type QueueStatsLog = string[]

export type ServerStats = {
  cpu: number
  fs: {
    r: number
    w: number
  }
  mem: {
    active: number
    used: number
  }
  net: {
    rx: number
    tx: number
  }
}

export type ServerStatsLog = string[]

export * from '@/autogen/entities'
export * from '@/autogen/models'
