import type { BadgeNames, PushNotificationDataMap } from '@/types'
import { getAccountFromId } from '@/utils/get-account-from-id'
import { charToFileName } from '@/utils/twemoji-base'
import { getUserName } from '@/utils/get-user-name'
import { cli } from '@/utils/operations'
import { swLang } from '@/utils/lang'

const closeNotificationsByTags = async (tags: string[]) => {
  for (
    const n of (
      await Promise.all(
        tags.map((tag) => globalThis.registration.getNotifications({ tag }))
      )
    ).flat()
  ) {
    n.close()
  }
}

// How to add a new badge
//
//   1. Find the icon you want on https://tabler-icons.io and download the PNG
//   2. Run `vips resize <icon path> /tmp/icon.png 0.4`
//   3. Run `vips scRGB2BW /tmp/icon.png <output path>"[compression=9,strip]"`
//   4. Run `rm /tmp/icon.png`
//   5. Run `mv <output path> <akkordian path>/packages/backend/assets/tabler-badges`
//   6. Add the filename to `BadgeNames`
const iconUrl = (name: BadgeNames) => `/static-assets/tabler-badges/${name}.png`

async function composeNotification(data: PushNotificationDataMap[keyof PushNotificationDataMap]): Promise<[string, NotificationOptions] | null> {
  const i18n = await (swLang.i18n ?? swLang.fetchLocale())
  const { t } = i18n

  switch (data.type) {
    case 'notification':
      switch (data.body.type) {
        case 'follow':
          const account = await getAccountFromId(data.userId)

          if (!account) { return null }

          const userDetail = await cli.request('users/show', { userId: data.body.userId }, account.token)
      }
  }
}
